@@ -25,19 +25,19 @@ from .managers import BulkManager
 p = PraatLoader(settings.PRAAT_PATH)
 
 class WTManager(BulkManager):
-    tbl_name = "buckeye_wordtoken"
+    tbl_name = "buckeyebrowser_wordtoken"
     cols = ['id','Begin','End','WordType_id','Category_id','Dialog_id','DialogPart']
 
 class STManager(BulkManager):
-    tbl_name = "buckeye_segmenttoken"
+    tbl_name = "buckeyebrowser_segmenttoken"
     cols = ['id','WordToken_id','SegmentType_id','Begin','End']
 
 class PCManager(BulkManager):
-    tbl_name = 'buckeye_prevcondprobs'
+    tbl_name = 'buckeyebrowser_prevcondprobs'
     cols = ['id','ActWord_id','PreviousWord_id','Count','Prob']
 
 class FCManager(BulkManager):
-    tbl_name = 'buckeye_follcondprobs'
+    tbl_name = 'buckeyebrowser_follcondprobs'
     cols = ['id','ActWord_id','FollowingWord_id','Count','Prob']
 
 class Speaker(models.Model):
